Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(48)

Unified Diff: content/browser/media/webrtc_internals.h

Issue 1272223003: Implement writing mic audio input data to file for debugging purposes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/media/webrtc_internals.cc » ('j') | content/browser/media/webrtc_internals.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/media/webrtc_internals.h
diff --git a/content/browser/media/webrtc_internals.h b/content/browser/media/webrtc_internals.h
index 8ad1f2cba7bbc664409d036704bb99c564eb8504..058ceda753970a178bc526a5348f680489c37b59 100644
--- a/content/browser/media/webrtc_internals.h
+++ b/content/browser/media/webrtc_internals.h
@@ -87,16 +87,16 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
// Sends all update data to |observer|.
void UpdateObserver(WebRTCInternalsUIObserver* observer);
- // Enables or disables AEC dump (diagnostic echo canceller recording).
- void EnableAecDump(content::WebContents* web_contents);
- void DisableAecDump();
+ // Enables or disables diagnostic audio recordings for debugging purposes.
+ void EnableAudioDebugRecordings(content::WebContents* web_contents);
+ void DisableAudioDebugRecordings();
- bool aec_dump_enabled() {
- return aec_dump_enabled_;
+ bool audio_debug_recordings_enabled() {
+ return audio_debug_recordings_;
}
- base::FilePath aec_dump_file_path() {
- return aec_dump_file_path_;
+ base::FilePath audio_debug_recordings_file_path() {
tommi (sloooow) - chröme 2015/08/07 12:09:51 nit: return const & and make the method const? al
Henrik Grunell 2015/08/17 15:05:16 Agree, done.
+ return audio_debug_recordings_file_path_;
}
void ResetForTesting();
@@ -128,8 +128,9 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
void OnRendererExit(int render_process_id);
#if defined(ENABLE_WEBRTC)
- // Enables AEC dump on all render process hosts using |aec_dump_file_path_|.
- void EnableAecDumpOnAllRenderProcessHosts();
+ // Enables diagnostic audio recordings on all render process hosts using
+ // |audio_debug_recordings_file_path_|.
+ void EnableAudioDebugRecordingsOnAllRenderProcessHosts();
#endif
// Called whenever an element is added to or removed from
@@ -167,9 +168,9 @@ class CONTENT_EXPORT WebRTCInternals : public RenderProcessHostObserver,
// For managing select file dialog.
scoped_refptr<ui::SelectFileDialog> select_file_dialog_;
- // AEC dump (diagnostic echo canceller recording) state.
- bool aec_dump_enabled_;
- base::FilePath aec_dump_file_path_;
+ // Diagnostic audio recording state.
+ bool audio_debug_recordings_;
+ base::FilePath audio_debug_recordings_file_path_;
// While |peer_connection_data_| is non-empty, hold an instance of
// PowerSaveBlocker. This prevents the application from being suspended while
« no previous file with comments | « no previous file | content/browser/media/webrtc_internals.cc » ('j') | content/browser/media/webrtc_internals.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698